<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>EditShare</name>
    <message>
        <location filename="../editshare.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="20"/>
        <source>&amp;Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="30"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="37"/>
        <source>&amp;Path</source>
        <translation>Yol</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="51"/>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="56"/>
        <source>No</source>
        <translation>Hayır</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="64"/>
        <source>&amp;Comment</source>
        <translation>Yorum</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="77"/>
        <source>&amp;Guest OK</source>
        <translation>&amp;Misafir TAMAM</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="111"/>
        <source>Access rights for valid users</source>
        <translation>Geçerli kullanıcılar için erişim hakları</translation>
    </message>
    <message>
        <location filename="../editshare.cpp" line="52"/>
        <source>Select directory to share</source>
        <translation>Paylaşılacak dizini seçin</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>&amp;Shares</source>
        <translation>&amp;Paylaşımlar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <source>Shares</source>
        <translation>Paylaşılanlar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba user shares found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Samba kullanıcı paylaşımı bulunamadı&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="50"/>
        <location filename="../mainwindow.ui" line="157"/>
        <source>&amp;Remove</source>
        <translation>&amp;Kaldır</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <location filename="../mainwindow.ui" line="164"/>
        <source>&amp;Add</source>
        <translation>%Ekle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>&amp;Edit</source>
        <translation>&amp;Düzenle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Name</source>
        <translation>Ad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Path</source>
        <translation>Yol</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Comment</source>
        <translation>Yorum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Permissions</source>
        <translation>İzinler</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Guest OK</source>
        <translation>Misafir TAMAM</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="142"/>
        <source>&amp;Users</source>
        <translation>Kullanıcılar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba users found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Samba kullanıcısı bulunamadı&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>&amp;Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Users</source>
        <translation>Kullanıcılar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <location filename="../mainwindow.cpp" line="296"/>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>E&amp;nable Automatic Samba Startup</source>
        <translation>Samba’nın Otomatik Başlamasını Etki&amp;nleştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Star&amp;t Samba</source>
        <translation>Samba’yı Başla&amp;t</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>Samba autostart service is disabled</source>
        <translation>Samba otomatik başlatma servisi devre dışı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Samba is running</source>
        <translation>Samba çalışıyor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>A&amp;bout...</source>
        <translation>&amp;Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Display help </source>
        <translation>Yardımı görüntüle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="409"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="104"/>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="136"/>
        <location filename="../mainwindow.cpp" line="147"/>
        <location filename="../mainwindow.cpp" line="203"/>
        <location filename="../mainwindow.cpp" line="276"/>
        <location filename="../mainwindow.cpp" line="287"/>
        <location filename="../mainwindow.cpp" line="386"/>
        <location filename="../mainwindow.cpp" line="418"/>
        <location filename="../mainwindow.cpp" line="422"/>
        <location filename="../mainwindow.cpp" line="428"/>
        <location filename="../mainwindow.cpp" line="433"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <location filename="../mainwindow.cpp" line="476"/>
        <location filename="../mainwindow.cpp" line="482"/>
        <location filename="../mainwindow.cpp" line="503"/>
        <location filename="../mainwindow.cpp" line="520"/>
        <location filename="../mainwindow.cpp" line="539"/>
        <location filename="../mainwindow.cpp" line="554"/>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>Error, could not add share. Empty share name</source>
        <translation>Hata, paylaşım eklenemedi. Paylaşım adı boş</translation>
    </message>
    <message>
        <source>Path: %1 doesn&apos;t exist.</source>
        <translation type="vanished">Yol: %1 mevcut değil.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>Yes</source>
        <translation>Evet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <source>Path: %1 does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>Could not add share. Error message:

%1</source>
        <translation>Paylaşım eklenemedi. Hata mesajı:

%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="147"/>
        <source>Error listing users</source>
        <translation>Kullanıcıları listeleme hatası</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>&amp;Deny</source>
        <translation>Re&amp;ddet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="187"/>
        <source>&amp;Read Only</source>
        <translation>&amp;Sadece oku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="188"/>
        <source>&amp;Full Access</source>
        <translation>&amp;Tam erişim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>Error listing shares</source>
        <translation>Paylaşım listeleme hatası</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="277"/>
        <source>Your user doesn&apos;t belong to &apos;sambashare&apos; group  if you just installed the app you might need to restart the system first.</source>
        <translation>Kullanıcı adınız ‘sambashare’ grubuna ait değildir, uygulamayı yeni yüklediyseniz, önce sistemi yeniden başlatmanız gerekebilir.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>Samba is not installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Sto&amp;p Samba</source>
        <translation>Samba’yı &amp;durdur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Samba is not running</source>
        <translation>Samba çalışmıyor</translation>
    </message>
    <message>
        <source>Samba not installed</source>
        <translation type="vanished">Samba yüklü değil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Samba autostart is enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Samba autostart is disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>&amp;Disable Automatic Samba Startup</source>
        <translation>&amp;Otomatik Samba Başlatmayı Devre Dışı Bırak</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>About %1</source>
        <translation>%1 Hakkında </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>MX Samba Config</source>
        <translation>MX Samba Yapılandırması</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>Program for configuring Samba shares and users.</source>
        <translation>Samba paylaşımlarını ve kullanıcılarını yapılandırma programı.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Telif Hakkı (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="368"/>
        <source>%1 License</source>
        <translation>%1 Lisans</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>%1 Help</source>
        <translation>%1 Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>Cannot delete user: </source>
        <translation>Kullanıcı silinemiyor:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Enter the username and password:</source>
        <translation>Kullanıcı adını ve şifreyi girin:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <location filename="../mainwindow.cpp" line="457"/>
        <source>Password:</source>
        <translation>Parola:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>Confirm password:</source>
        <translation>Parolayı onayla:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>Empty username, please enter a name.</source>
        <translation>Kullanıcı adı boş, lütfen bir ad girin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="423"/>
        <source>Matching linux user not found on system, make sure you enter a valid username.</source>
        <translation>Sistemde eşleşen linux kullanıcısı bulunamadı, geçerli bir kullanıcı adı girdiğinizden emin olun.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <location filename="../mainwindow.cpp" line="476"/>
        <source>Passwords don&apos;t match, please enter again.</source>
        <translation>Şifreler eşleşmiyor, lütfen tekrar girin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Could not add user.</source>
        <translation>Kullanıcı eklenemedi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <location filename="../mainwindow.cpp" line="492"/>
        <location filename="../mainwindow.cpp" line="498"/>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>No user selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>Change the password for &apos;%1&apos;</source>
        <translation>‘%1’ şifresini değiştirin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>Password fields cannot be empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="482"/>
        <source>Could not change password.</source>
        <translation>Parola değiştirilemedi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>No share selected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="498"/>
        <source>Selected share is empty.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Cannot delete share: </source>
        <translation>Paylaşım silinemiyor:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Share deleted successfully: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <location filename="../mainwindow.cpp" line="570"/>
        <source>Samba service is not running. Please start Samba before adding or editing shares</source>
        <translation>Samba hizmeti çalışmıyor. Paylaşımları eklemeden veya düzenlemeden önce lütfen Samba’yı başlatın</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <location filename="../mainwindow.cpp" line="554"/>
        <source>Error processing permissions: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error: trying to process permissions: </source>
        <translation type="vanished">Hata: izinler işlenmeye çalışılıyor:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>You must run this program as normal user.</source>
        <translation>Bu programı normal kullanıcı olarak çalıştırmalısınız.</translation>
    </message>
</context>
</TS>
